projectal.entities.access_policy API documentation

# projectal.entities.access_policy

View Source

     1from projectal.entity import Entity
     2from projectal.linkers import PermissionLinker, UserLinker
     3
     4
     5class AccessPolicy(Entity, PermissionLinker, UserLinker):
     6    """
     7    Implementation of the [Access Policy](https://projectal.com/docs/latest/#tag/Access-Policy) API.
     8    """
     9
    10    _path = "access-policy"
    11    _name = "access_policy"
    12
    13    _links = [PermissionLinker]
    14    _links_reverse = [UserLinker]

class AccessPolicy(projectal.entity.Entity, projectal.linkers.PermissionLinker, projectal.linkers.UserLinker): View Source

     6class AccessPolicy(Entity, PermissionLinker, UserLinker):
     7    """
     8    Implementation of the [Access Policy](https://projectal.com/docs/latest/#tag/Access-Policy) API.
     9    """
    10
    11    _path = "access-policy"
    12    _name = "access_policy"
    13
    14    _links = [PermissionLinker]
    15    _links_reverse = [UserLinker]

Implementation of the Access Policy API.

##### Inherited Members

projectal.entity.Entity
  get
  update
  delete
  history
  create
  save
  clone
  list
  match
  match_startswith
  match_endswith
  match_one
  match_startswith_one
  match_endswith_one
  search
  query
  profile_get
  profile_set
  changes
  set_readonly
  get_link_definitions
  entity_name
projectal.linkers.PermissionLinker
  link_permission
  unlink_permission
projectal.linkers.UserLinker
  link_user
  unlink_user